@@ -1,7 +1,7 @@
 __project_name__ = 'tofipa'
 __description__ = 'Get download directory from torrent file'
-__homepage__ = 'https://codeberg.org/ormaybe/tofipa'
-__version__ = '0.1.0'
+__homepage__ = 'https://codeberg.org/plotski/tofipa'
+__version__ = '0.2.0'
 __author__ = 'plotski'
 __author_email__ = 'plotski@example.org'
 
