@@ -13,6 +13,7 @@ def _parse_args(args):
     )
     argparser.add_argument(
         'TORRENT',
+        nargs='+',
         help='Path to torrent file',
     )
     argparser.add_argument(
@@ -121,9 +122,9 @@ def _get_client(args):
             return _btclient.Client(config)
 
 
-def _find_location(args):
+def _find_location(torrent, args):
     location_finder = _location.FindDownloadLocation(
-        torrent=args.TORRENT,
+        torrent=torrent,
         locations=_get_locations(args),
         default=args.default,
     )
@@ -133,22 +134,32 @@ def _find_location(args):
         _fatal_error(str(e))
 
 
+async def _handle_location(location, torrent, client):
+    if client:
+        response = await client.add_torrent(torrent, location)
+        for warning in response.warnings:
+            sys.stderr.write(f'{torrent}: WARNING: {warning}\n')
+        if response.errors:
+            for error in response.errors:
+                sys.stderr.write(f'{torrent}: {error}\n')
+            return False  # Failure
+        return True  # Success
+    else:
+        sys.stdout.write(f'{location}\n')
+        return True  # Success
+
+
 async def _cli(args):
     args = _parse_args(args)
     _setup_debugging(args)
     client = _get_client(args)
-    location = _find_location(args)
 
-    if client:
-        response = await client.add_torrent(args.TORRENT, location)
-        for warning in response.warnings:
-            sys.stderr.write(f'WARNING: {warning}\n')
-        if response.errors:
-            for error in response.errors:
-                sys.stderr.write(f'{error}\n')
-            return 1
-    else:
-        sys.stdout.write(f'{location}\n')
+    exit_code = 0
+    for torrent in args.TORRENT:
+        location = _find_location(torrent, args)
+        if not await _handle_location(location, torrent, client):
+            exit_code = 1
+    return exit_code
 
 
 def cli():
